import React, { useEffect, useState } from 'react';
import { Link, useParams } from 'react-router-dom';
import SearchBar from '../components/SearchBar';
import { Button, Form, Modal } from 'react-bootstrap';
import { useSelector, useDispatch } from 'react-redux';
import { fetchBrands, fetchBrandDetail, fetchCampaignDetail, setSelectedProduct } from '../store/slices/brandsSlice';
import CampaignInfo from '../components/CampaignInfo';
import { ChevronRight, Send, Plus } from 'lucide-react';
import ProductsList from '../components/ProductsList';
import SlidePanel from '../components/SlidePanel';
import CampaignScript from './CampaignScript';
import { addProductToCampaign, fetchProducts } from '../store/slices/productSlice';

export default function CampaignDetail() {
    const { brandId, campaignId } = useParams();
    const dispatch = useDispatch();
    const { brands, selectedBrand, selectedCampaign } = useSelector((state) => state.brands);
    const progressList = ['Find', 'Review', 'Confirmed', 'Draft Ready', 'Published'];
    const [progressIndex, setProgressIndex] = useState(2);
    const [activeTab, setActiveTab] = useState('products');
    const [showProductDetail, setShowProductDetail] = useState(false);
    const [showAddProductModal, setShowAddProductModal] = useState(false);

    useEffect(() => {
        if (brandId && campaignId) {
            if (!selectedBrand?.id) {
                dispatch(fetchBrandDetail(brandId));
                dispatch(fetchCampaignDetail(campaignId));
            } else {
                dispatch(fetchCampaignDetail(campaignId));
            }
        }
        dispatch(fetchProducts());
    }, [dispatch, brandId, campaignId]);

    const handleShowProductDetail = (product) => {
        dispatch(setSelectedProduct(product));
        setShowProductDetail(true);
    };

    return (
        selectedCampaign?.id && (
            <div className='campaign-detail'>
                <div className='breadcrumb'>
                    <Link to={'/brands'} className='breadcrumb-item'>
                        Brands
                    </Link>
                    <Link to={`/brands/${brandId}`} className='breadcrumb-item'>
                        {selectedBrand.name}
                    </Link>
                    <div className='breadcrumb-item'>{selectedCampaign.name}</div>
                </div>
                <div className='function-bar'>
                    <SearchBar />
                    <Button>
                        <Send size={18} />
                        Email
                    </Button>
                </div>
                <CampaignInfo />
                <Form className='campaign-requirements shadow-xs'>
                    <Form.Group className='mb-3 additional_requirements' controlId='additional_requirements'>
                        <Form.Label>Additional Requirements</Form.Label>
                        <Form.Control type='text' placeholder='xxx' />
                    </Form.Group>
                    <Form.Group className='mb-3 creator_requirements' controlId='creator_requirements'>
                        <Form.Label>Creators</Form.Label>
                        <Form.Control type='number' />
                    </Form.Group>
                    <Button type='submit' variant='primary-subtle'>
                        Match Creators
                    </Button>
                </Form>
                <div className='campaign-progress shadow-xs'>
                    {progressList.map((item, index) =>
                        index < progressList.length - 1 ? (
                            <React.Fragment key={index}>
                                <div
                                    className={`campaign-progress-item ${progressIndex === index ? 'active' : ''}`}
                                    key={index}
                                >
                                    <div className='campaign-progress-item-index'>{index + 1}</div>
                                    <div className='campaign-progress-item-label'>{item}</div>
                                    <div className='campaign-progress-item-desc'>xx Creators</div>
                                </div>
                                <ChevronRight />
                            </React.Fragment>
                        ) : (
                            <div
                                className={`campaign-progress-item ${progressIndex === index ? 'active' : ''}`}
                                key={index}
                            >
                                <div className='campaign-progress-item-index'>{index + 1}</div>
                                <div className='campaign-progress-item-label'>{item}</div>
                                <div className='campaign-progress-item-desc'>xx Creators</div>
                            </div>
                        )
                    )}
                </div>
                <div className='campaign-tab-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'products' ? 'active' : ''}`}
                        onClick={() => setActiveTab('products')}
                    >
                        Products
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'accepted_creators' ? 'active' : ''}`}
                        onClick={() => setActiveTab('accepted_creators')}
                    >
                        Accepted Creators
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'matching_result' ? 'active' : ''}`}
                        onClick={() => setActiveTab('matching_result')}
                    >
                        Matching Result
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'email_draft' ? 'active' : ''}`}
                        onClick={() => setActiveTab('email_draft')}
                    >
                        Email Draft
                    </div>
                </div>

                {activeTab === 'products' && (
                    <>
                        <Button
                            className='add-product-btn'
                            variant='outline-primary'
                            onClick={() => setShowAddProductModal(true)}
                        >
                            <Plus size={18} />
                            Add Product
                        </Button>
                        <ProductsList products={selectedCampaign?.link_product_details} onShowProductDetail={handleShowProductDetail} />
                        <SlidePanel
                            show={showProductDetail}
                            onClose={() => setShowProductDetail(false)}
                            title='Product Detail'
                            size='xxl'
                        >
                            <CampaignScript  />
                        </SlidePanel>
                        <AddProductModal campaignId={campaignId} show={showAddProductModal} onHide={() => setShowAddProductModal(false)} />
                    </>
                )}
            </div>
        )
    );
}

function AddProductModal({ campaignId, show, onHide }) {
    const [selectedProduct, setSelectedProduct] = useState(null);
    const { products } = useSelector((state) => state.products);
    const dispatch = useDispatch();

    const handleCancel = () => {
        onHide();
        setSelectedProduct(null);
    };

    const handleSubmit = async () => {
        if (!selectedProduct) return;
        console.log(selectedProduct);
        await dispatch(addProductToCampaign({ campaignId, productId: selectedProduct })).unwrap();
        dispatch(fetchCampaignDetail(campaignId));
        handleCancel();
    };

    return (
        <Modal show={show} onHide={handleCancel}>
            <Modal.Header closeButton className='fw-bold'>
                Add Product
            </Modal.Header>
            <Modal.Body>
                <Form className='add-product-form'>
                    <Form.Group className='mb-3'>
                        <Form.Label>Product PID</Form.Label>
                        <Form.Select
                            aria-label='Default select example'
                            value={selectedProduct}
                            onChange={(e) => setSelectedProduct(e.target.value)}
                        >
                            <option>Select</option>
                            {products?.length > 0 && products.map((product) => (
                                <option key={product.id} value={product.id}>
                                    {product.name}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <div className='button-group'>
                        <Button variant='outline-light' className='text-primary' onClick={handleCancel}>
                            Cancel
                        </Button>
                        <Button variant='primary' onClick={handleSubmit}>
                            Create
                        </Button>
                    </div>
                </Form>
            </Modal.Body>
        </Modal>
    );
}
